@@ -1,3 +1,5 @@
+import json
+
 from cgdb.resources.elementContext import ElementContext
 from cgdb.utils.ManagerMix import ManagerMix
 
@@ -22,12 +24,22 @@ class ElementContextsManager(ManagerMix):
 
         return ElementContext(**content, client=self._client)
 
-    def element_context_by_element(self, element_mark: str, aggregation: str, timestamp_code: str):
+    def element_context_by_element(self, element_mark: str, aggregation: str, timestamp_code: str, level_code:str = None):
         if self.elementContextsCached is None:
             self.elementContextsCached = self.element_contexts()
 
         for elementContext in self.elementContextsCached:
-            if elementContext.aggregation == aggregation and elementContext.element.mark == element_mark and elementContext.time_step.code == timestamp_code:
+            if elementContext.aggregation == aggregation and elementContext.element.mark == element_mark and elementContext.time_step.code == timestamp_code and (level_code is not None and elementContext.levelId is not None and elementContext.level.code == level_code):
                 return elementContext
 
-        return None
\ No newline at end of file
+        return None
+    
+    def create_element_context(self, element, aggregation, timeStep, level=None):
+        content = {"elementId": element.id,
+                   "timeStepId": timeStep.id,
+                   "aggregation": aggregation}
+
+        if level is not None:
+            content["levelId"] = level.id
+
+        self.post('element-contexts', json.dumps(content))
